### A Pluto.jl notebook ###
# v0.19.27

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ 20222023-0236-0003-0000-000000000000
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, PlutoTeachingTools
	using CSV, DataFrames, Dates, PeriodicalDates, StatsBase
end

# ╔═╡ 20222023-0236-0003-0000-000000000003
function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
    # Remove responsive flag on the plot as we handle responsivity via ResizeObeserver and leaving it on makes the div flickr during updates
 hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
 show(io,mimetype, @htl("""
         <div>
         <script id=asdf>
         const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
         const PLOT = this ?? document.createElement("div");
     

     
         Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


     
         const pluto_output = currentScript.parentElement.closest('pluto-output')

         const resizeObserver = new ResizeObserver(entries => {
             Plotly.Plots.resize(PLOT)
         })

         resizeObserver.observe(pluto_output)

         invalidation.then(() => {
             resizeObserver.disconnect()
         })
     
         return PLOT
         </script>
         </div>
 """))
end;

# ╔═╡ 20222023-0236-0003-0000-000000000004
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
<title>Macroeconomia</title>
<subtitle>Exame Modelo</subtitle>
<semester>Licenciatura em Gestão<br>1º Semestre 2022-23</semester>
<author>Vivaldo Mendes, Luís Clemente-Casinhas, Ricardo Gouveia-Mendes</author>
"""

# ╔═╡ 20222023-0236-0003-0000-000000000005
@bind nome TextField(66, placeholder="Nome")

# ╔═╡ 20222023-0236-0003-0000-000000000006
@bind numero TextField(placeholder="Número de aluno")

# ╔═╡ 20222023-0236-0003-0000-000000000007
md"""
> O teste é composto por 40 questões de **escolha múltipla**. Em cada questão, selecione **a alternativa correta**, a menos que lhe seja indicada outra coisa.
>
> Cada pergunta de escolha múltipla tem a cotação de **0.5 pontos**.
>
> Respostas **erradas descontam -0.125 pontos**.
>
> É esperado que este teste modelo **demore apenas 1h a responder**.
>
> ---
>
> **NOTA:** O teste a sério conterá 50 perguntas e o tempo de resolução será de 1h30.
"""

# ╔═╡ 46598cde-557e-4564-958b-9d3c3df029ed
Resource("https://vivaldomendes.org/images/Tests/Cycles_France.svg")

# ╔═╡ 20222023-0236-0003-0001-000000000001
md"""
A figura acima apresenta os ciclos económicos de curto prazo para a França entre 1950 e 2021. Dois anos em que a França esteve numa profunda recessão económica são:

**a)** 2009 e 2020.

**b)** 1980 e 1990.

**c)** 1960 e 1970.

**d)** 1975 e 2000.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0001-000000000002
@bind q01 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0002-000000000001
md"""
Para uma dada economia, sabe-se que: PIB = 98 e que PIB Potencial = 100. Selecione a opção correta.

**a)** A economia encontra-se numa recessão e o hiato do produto é igual a 2.

**b)** A economia encontra-se num boom económico e o hiato do produto é igual a -2.

**c)** A economia encontra-se numa recessão e o hiato do produto é igual a -2.

**d)** A economia encontra-se num boom económico e o hiato do produto é igual a 2.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0002-000000000002
@bind q02 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0003-000000000001
md"""
Num modelo macroeconómico as variáveis endógenas são:

**a)** variáveis cujo valor é determinado fora do modelo.

**b)** variáveis geradas internamente num determinado país ou área geográfica.

**c)** variáveis cuja valor ou evolução se pretendem explicar com o modelo.

**d)** variáveis cujo comportamento não se consegue explicar.

**e)** variáveis sobre as quais não há consenso científico.
"""

# ╔═╡ 20222023-0236-0003-0003-000000000002
@bind q03 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0004-000000000001
md"""
Num modelo macroeconómico existem variáveis endógenas e exógenas. Selecione a opção falsa sobre variáveis endógenas:

**a)** São determinadas dentro de um modelo.

**b)** Não podem determinar variáveis exógenas.

**c)** Podem determinar outras variáveis endógenas.

**d)** Não são sempre determinadas por variáveis exógenas.

**e)** São determinadas fora de um modelo económico.
"""

# ╔═╡ 20222023-0236-0003-0004-000000000002
@bind q04 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0005-000000000000
md"""
Considere uma economia onde apenas se produzem os seguintes bens:

| Bens  |   |  $~~~~~~~~~~~~~~$ Ano 1 |      |    ||$~~~~~~~~~~~~~~$Ano 2||
|:----  |---| :----:         | :----: |   ---|--- |:----:        | :----: |
|       |   | Quantidades    | Preços |      |    |Quantidades   | Preços |
|Leite  |   | 5000           | 2      |      |    |4900          | 2.1    |
|Pão    |   | 1000           | 1.5    |      |    |1400          | 1.6    |

"""

# ╔═╡ 20222023-0236-0003-0005-000000000001
md"""
O PIB nominal para os anos 1 e 2, será respetivamente:

**a)** PIB1 = 12530; PIB2 = 11500.

**b)** PIB1 = 11500; PIB2 = 12530.

**c)** PIB1 = 15000; PIB2 = 10000.

**d)** PIB1 = 10000; PIB2 = 15000.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ a427ead0-0317-4c00-9cf8-fb162cd771c2
# Célula livre para cálculos

# ╔═╡ 5a10b2ee-1cc6-4bdd-b793-d7e584b410e5
# Célula livre para cálculos

# ╔═╡ 38424a48-bc9e-471d-9773-171fd8effb55
# Célula livre para cálculos

# ╔═╡ 20222023-0236-0003-0005-000000000002
@bind q05 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0006-000000000001
md"""
As imputações especiais associadas ao cálculo do PIB servem para:

**a)** Incluir no PIB o valor dos Bens & Serviços que não sejam sujeitos a transações de mercado.

**b)** Incluir no PIB as transações de Bens & Serviços que não são declaradas ao fisco.

**c)** Incluir no PIB as transações de Bens & Serviços que são ilegais.

**d)** Evitar aumentos artificiais do PIB por contabilização duplicada.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0006-000000000002
@bind q06 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0007-000000000001
md"""
Considere uma economia simples onde há dois bens: uvas e vinho. Sabe-se que esta economia produz 1000 dólares de uvas e 5000 dólares de vinho, e as empresas vinícolas compram toda a uva para produzir vinho. Com base nesta informação, que métodos podem ser utilizados para calcular o valor do PIB neste caso?

**a)** O método da despesa e o método do rendimento.

**b)** O método da produção e o método do rendimento.

**c)** Apenas o método da despesa.

**d)** Apenas o método da produção.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0007-000000000002
@bind q07 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0008-000000000001
md"""
A TAP vendeu à Airbus no Reino Unido, aviões usados no valor de 0.5 milhões para pagar uma certa indemnização. O impacto da operação de venda dos aviões no PIB é de:

**a)** Aumentar em 0.5 milhões.

**b)** Diminuir em 0.5 milhões.

**c)** A operação não tem impacto no PIB.

**d)** Não há dados suficientes para calcular o impacto sobre o PIB.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0008-000000000002
@bind q08 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0009-000000000010
let
C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
m = 1/(1-c)
ϕ = b + d + x

Y = 0.0:0.01:15.0	
r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
trace4_1 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
name  = "IS")

trace4_2 = scatter(; x = [6.0, 9.0], y = [3.0, 1.0], text =["1", "2"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Blue", 
textfont = attr(family="sans serif", size=16, color="black"))


trace4_4A = scatter(; x = [7.0, 8.0], y = [1.0, 3.0], text =["2'", "1'"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Red", 
textfont = attr(family="sans serif", size=16, color="black"))

layout4_2 = Layout(;
title_text = "A Curva IS", 
title_x = 0.5,
hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

p4_2 = Plot([trace4_1, trace4_2, trace4_4A], layout4_2)

end

# ╔═╡ 20222023-0236-0003-0009-000000000001
md"""
Usando a figura "A Curva IS" e sabendo que $m=2$, a economia desloca-se do ponto 2 para o ponto 2', devido ao facto de:

**a)** O Consumo Exógeno (C̄) ter aumentado em 1 trilião de dólares.

**b)** O Consumo Exógeno (C̄) ter diminuído em 1 trilião de dólares.

**c)** A taxa de juro real (r) ter diminuído em 1 ponto percentual (1 pp).

**d)** O Consumo Exógeno (C̄) ter diminuído em 2 triliões de dólares.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0009-000000000002
@bind q09 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0010-000000000001
md"""
Qual o significado económico da Procura Autónoma?

**a)** É uma variável endógena que representa um valor de bens e serviços desejados numa certa economia que não é sensível a variações da taxa de juro.

**b)** É uma variável exógena que representa um valor de bens e serviços desejados numa certa economia que não é sensível a variações da taxa de juro.

**c)** É uma variável endógena que representa um valor de bens e serviços desejados numa certa economia que não é sensível a variações da taxa de inflação.

**d)** É uma variável exógena que representa um valor de bens e serviços desejados numa certa economia que é sensível a variações da taxa de juro.

**e)** É uma variável exógena que representa um valor de bens e serviços desejados numa certa economia que é sensível a variações da taxa de inflação.
"""

# ╔═╡ 20222023-0236-0003-0010-000000000002
@bind q10 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 9031631e-3aa7-46de-973d-dbfa668bf18b
md"""
No mercado de Bens&Serviços é conhecida a seguinte informação: 

$$\overline{C} =2  \quad , \quad  \overline{I} =1.5 \quad , \quad \overline{G} = 2.5 \quad , \quad \overline{T} =2.5 \quad , \quad \overline{N X}= 1$$

$$\overline{f}  =1 \quad , \quad c=0.5 \quad , \quad b=0.1 \quad , \quad d=0.5 \quad , \quad x=0.15$$


A função IS encontra-se representada na figura seguinte. Quantifique duas alterações na Procura Autónoma que movam a economia do ponto 1 para o ponto 3.
"""

# ╔═╡ bece237e-83f1-41b5-a759-1c2934ddc57b
let
C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
m = 1/(1-c)
ϕ = b + d + x

Y = 0.0:0.01:15.0	
r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
trace4_1 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
name  = "IS")

trace4_2 = scatter(; x = [6.0, 9.0], y = [3.0, 1.0], text =["1", "2"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Blue", 
textfont = attr(family="sans serif", size=16, color="black"))


trace4_4A = scatter(; x = [7.0, 9.0], y = [1.0, 3.0], text =["2'", "3"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Red", 
textfont = attr(family="sans serif", size=16, color="black"))

layout4_2 = Layout(;
title_text = "A Curva IS", 
title_x = 0.5,
hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

p4_2 = Plot([trace4_1, trace4_2, trace4_4A], layout4_2)

end

# ╔═╡ 20222023-0236-0003-0011-000000000001
md"""

**a)** $\Delta\overline{NX} = 0.75$ e $\Delta\overline{I} = 0.75$.

**b)** $\Delta\overline{NX} = -2$ e $\Delta\overline{I} = -2$.

**c)** $\Delta\overline{I} = 2$ e $\Delta m = 2$.

**d)** $\Delta\overline{G} = -2$ e $\Delta\overline{T} = 2$.

**e)** $\Delta\overline{G} = -2$ e $\Delta m = 2$.
"""

# ╔═╡ 20222023-0236-0003-0011-000000000002
@bind q11 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 2d8c34ef-9697-4d36-a66c-83fc800ef447
let
C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
m = 1/(1-c)
ϕ = b + d + x

Y = 0.0:0.01:15.0	
r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
	
	trace4_0 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "IS")
	
	layout4_0 = Layout(;
					title_text ="IS curve", 
					title_x = 0.5,
					hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
					yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

   p4_0 = Plot([trace4_0], layout4_0)
	
end

# ╔═╡ 20222023-0236-0003-0012-000000000001
md"""
Usando a função IS acima representada, se a taxa de juro real aumentar 2p.p., o efeito no PIB será:

**a)** Aumentar 2 triliões.

**b)** Diminuir 3 triliões.

**c)** Nulo, pois a inflação acompanhará a subida da taxa de juro.

**d)** Nulo, pois haverá uma diminuição das exportações, em virtude de uma apreciação da moeda.

**e)** Nulo, pois haverá simplesmente uma transferência de consumo para a poupança, em virtude da taxa de juro ser mais alta.
"""

# ╔═╡ 20222023-0236-0003-0012-000000000002
@bind q12 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ be4a5d64-8da8-419e-9b5c-4b66aac99cc4
html"""
<img src="https://vivaldomendes.org/images/Tests/MP.png" style="width:500px" />
"""

# ╔═╡ 20222023-0236-0003-0013-000000000001
md"""
Inspecionando a figura acima, o deslocamento da curva MP da posição 1 para a posição 2 significa que:

**a)** A taxa de inflação diminui para cada nível da taxa de juro real.

**b)** A taxa de inflação aumenta para cada nível da taxa de juro real.

**c)** Não existe qualquer relação entre a taxa de juro real e a taxa de inflação.

**d)** A taxa de inflação permanece constante cada nível da taxa de juro real.

**e)** Nenhuma das anteriores
"""

# ╔═╡ 20222023-0236-0003-0013-000000000002
@bind q13 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0014-000000000001
md"""
O banco central fixa a taxa de juro real de curto prazo, baseando-se nas 2 seguintes variáveis:

**a)** O PIB e a deflação.

**b)** O desemprego, e o PIB.

**c)** A taxa de juro nominal, e a inflação

**d)** O PIB, e o índice de preços.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0014-000000000002
@bind q14 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b31c69f6-b072-4e95-aada-3d07a0e89481
begin
		Ā3 = 7.6 ;	λ3 = 0.5 ;	m3 = 2.0 ;	ϕ3 = 0.2 ;	r̄3 = 2.0 ;		
		r3 = 1.5:0.01:7.0
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
function fig_3b1()
		
		r3 = 1.5:0.01:7.0
	
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
	
		trace5_5 = scatter(; x = r3, y = π3, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
	
		layout5_5 = Layout(;
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [1.5, 6.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_5 = Plot([trace5_5], layout5_5)
		
	end
	#fig_3b1()

function fig_3b2()
		
		Y3 = 12.0:0.01:14.6
		πdmax3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 		# The AD curve y-axis intercept 
	
		πd3 = πdmax3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3)
	
		trace5_6 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "AD")
	
	
		layout5_6 = Layout(;
					title_text ="AD curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [12.6, 14.6],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_6 = Plot([trace5_6], layout5_6)
	end
	#fig_3b2()

	p5A_6A = [fig_3b1() fig_3b2()]
	relayout!(p5A_6A, hovermode = "y")
	p5A_6A
	
end

# ╔═╡ 20222023-0236-0003-0015-000000000001
md"""
As curvas AD e MP estão representadas acima. Se a inflação aumentar em de 2 p.p., qual será a reação do banco central?

**a)** A taxa de juro real será de cerca de 3.9%.

**b)** O PIB será de cerca de 10.2 triliões.

**c)** A taxa de juro definida pelo Banco Central será de cerca de 5.9%.

**d)** O banco central subirá a taxa de juro real em 1 p.p.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0015-000000000002
@bind q15 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f39350c4-2bf9-4e4a-8b8f-01bb4da07dc7

let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ;	ϕ5 = 0.3 ; r̄5 = 0.5 		   	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 					# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       							# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5   

	Y5 = 9.0:0.01:11.0
	
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) # AD function
	πs5 = πs_min5 .+ γ5 .*Y5             # AS function
	
	trace9_0 = scatter(; x = [10,10] , y = [-7,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_3 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])

	p9_3 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_3)

	r5 = 0.0:0.01:5.0
	
		πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5 
		
		trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")
		
		trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
						textposition = "top center", name ="", mode="markers+text", 
						marker_size= "12", marker_color="Brown", 
						textfont = attr(family="sans serif", size=18, color="black"))
		
		layout4_1 = Layout(;
						title_text = "MP Curve",
						title_x = 0.5,
						hovermode = "x",
	                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
	                    xaxis_range = [0.5, 3.5],
						#xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
						yaxis_range=[-0.0 , 6.0])
	
	   p4_1 = Plot([trace4_0, trace4_1], layout4_1)

[p4_1 p9_3]
end

# ╔═╡ 20222023-0236-0003-0016-000000000001
md"""
Levando em consideração as figuras acima, as quais representam o equilíbrio macroeconómico, quais dos valores abaixo correspondem a este equilíbrio:

**a)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$.

**b)** $\pi=10\% \ \  , \ \ Y = 3 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$.

**c)** $\pi=2.5\% \ \  , \ \ Y = 10 \ \ , \ \ r=5.5\% \ \ , \ \ i = 10.5\%$.

**d)** $\pi=0\% \ \  , \ \ Y = 10 \ \ , \ \ r=5\% \ \ , \ \ i = 5\%$.

**e)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=3\% \ \ , \ \ i = 6\%$.
"""

# ╔═╡ 20222023-0236-0003-0016-000000000002
@bind q16 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0017-000000000001
md"""
O multiplicador monetário não é, nos dias que correm, uma variável macroeconómica relevante pela seguinte razão:

**a)** É extremamente instável, mesmo no curto prazo.

**b)** O banco central não controla a Base Monetária; portanto, não controla este multiplicador. 

**c)** O banco central controla de forma perfeita a Oferta de Moeda (M2); portanto, controla totalmente este multiplicador.

**d)** Ninguém sabe como o multiplicador monetário é calculado.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0017-000000000002
@bind q17 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0018-000000000001
md"""
A *Discount Rate* usada pelo Fed serve para:

**a)** Multar os bancos comerciais que constituam reservas acima do limite legal.

**b)** Definir a percentagem do valor recebido em depósitos que não pode ser concedido em crédito.

**c)** Aumentar o multiplicador monetário.

**d)** Remunerar os bancos comerciais pelas reservas que constituíram junto do Banco Central.

**e)** Definir o preço sobre o crédito que o Banco Central concede aos bancos comerciais.
"""

# ╔═╡ 20222023-0236-0003-0018-000000000002
@bind q18 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0019-000000000000
md"""
O balanço do Fed (Federal Reserve Board), em 2021*:

| Assets              | $~~$ \$Billions  |       | Liabilities          | \$Billions
| :---------------    | ------------:    | :---: | :---------------     | -------:
| Foreign reserves    | 40               |       | Currency             | 2100
| Securities          | 8000             |       | Reserves     | 4400 
| Loans               | 100              |       | Other liabilities    | 1650
| Other assets        | 60               |       | Equity     | 50
| Total assets        | 8200             |       | Liabilities+Equity   | 8200

*Para efeitos de simplificação, estes valores são aproximados.
"""

# ╔═╡ 20222023-0236-0003-0019-000000000001
md"""
Qual era o valor da Base Monetária (MB) nos EUA em 2021:

**a)** 2100 + 4400 + 1650 biliões.

**b)** 8200 biliões.

**c)** 2100 + 4400 biliões.

**d)** 50 biliões.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ f87ae88e-587e-4b9a-98b7-b2e4f4d72f90
# Célula livre para cálculos

# ╔═╡ 20222023-0236-0003-0019-000000000002
@bind q19 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0020-000000000001
md"""
O que varia no balanço do Fed (Federal Reserve Board), se este banco proceder às seguintes transações?
- Vende 500 milhões de dólares em "Treasuries" (títulos de dívida pública dos EUA);
- Compra 800 milhões de dólares de "Mortgage-Backed Securities" (títulos hipotecários).

**a)** Securities = --500 milhões + 800 milhões ; Reservas = --500 milhões + 800 milhões.

**b)** Securities = +500 milhões -- 800 milhões ; Reservas = +500 milhões -- 800 milhões.

**c)** Securities = +1300 milhões ; Reservas = +1300 milhões.

**d)** Securities = --1300 milhões ; Reservas = --1300 milhões.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0020-000000000002
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0021-000000000000
let
output = 0:1:16
PC = 3.0 .+(0.5 .* 0.5).*(output .- 10.0)
trace7_24 = scatter(;x =output, y = PC, 
name = "AS", line_color = "Blue", mode = "lines", 
line_width="2.5") 
trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.5, 3.0 , 3.5], text = ["2", "1" , "3"], 
textposition = "top center", name = "", mode="markers+text", marker_size= "12",
marker_color="blue", 
textfont = attr(family="sans serif", size=16, color="black"))
trace7_49 = scatter(; x = [10.0, 10.0] , y = [-2,10] , mode = "line", line_width = "4", name = "Yp", 
line_color = "Orange") 
trace7_41 = scatter(; x = [8.0, 10.0, 12.0], y = [3.0, 3.5 , 4.0], text = ["2'", "1'" , "3'"], 
textposition = "top center", name = "", mode="markers+text", marker_size= "12",
marker_color="Red", 
textfont = attr(family="sans serif", size=16, color="black"))
layout7_25 = Layout(;
title_text = "The AS curve",
title_x = 0.5,
        yaxis_title = "Rate of Inflation",
yaxis_zeroline= false,
hovermode="x",
        xaxis_range = [6.0, 14.0],
        xaxis_title = "GDP (trillion dollars)",
xaxis_zeroline= false,
        yaxis_range=[2.0, 4.2], 
        titlefont_size=18) 
p7_25=Plot([trace7_49, trace7_24, trace7_25, trace7_41], layout7_25)
end

# ╔═╡ 20222023-0236-0003-0021-000000000001
md"""
Na figura acima, como justifica o deslocamento da curva AS do ponto 2 para 2’?

**a)** Um choque positivo sobre a AS em $-0.5$ pontos percentuais.

**b)** Uma subida do PIB em 2 triliões de dólares.

**c)** Uma descida do PIB em 2 triliões de dólares.

**d)** Um choque negativo sobre a AS em $+0.5$ pontos percentuais.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0021-000000000002
@bind q21 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0022-000000000001
md"""
A Lei de Okun diz-nos que:

**a)** Se o PIB $(Y)$ cair 1 ponto percentual, a taxa de desemprego $(U)$ aumentará cerca de 0.5 pontos percentuais.

**b)** Se o PIB $(Y)$ cair 1 ponto percentual, a taxa de desemprego $(U)$ diminuirá cerca de 0.5 pontos percentuais.

**c)** Se o PIB $(Y)$ cair 1 ponto percentual, a taxa de desemprego $(U)$ permanecerá inalterada.

**d)** Se o PIB $(Y)$ cair 1 ponto percentual, a taxa de desemprego $(U)$ aumentará 10 pontos percentuais.

**e)** Se o PIB $(Y)$ cair 1 ponto percentual, voltará ao seu valor inicial de forma automática.
"""

# ╔═╡ 20222023-0236-0003-0022-000000000002
@bind q22 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0023-000000000001
md"""
Um dos fenómenos que pode levar a uma deslocação para cima da Curva de Phillips é:

**a)** Uma diminuição do preço do pretróleo.

**b)** Um aumento da taxa de desemprego.

**c)** Uma diminuição da taxa de desemprego natural.

**d)** Um aumento da inflação esperada.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0023-000000000002
@bind q23 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0024-000000000001
md"""
A ideia por detrás da Curva de Phillips é que:

**a)** Pressões inflacionistas são a consequência da taxa de desemprego estar abaixo da taxa natural de desemprego.

**b)** Salários aumentam quando o PIB está abaixo do PIB potencial.

**c)** Pressões inflacionistas são a consequência da taxa de desemprego estar acima da taxa natural de desemprego.

**d)** Salários diminuem quando o PIB está acima do PIB potencial.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0024-000000000002
@bind q24 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0025-000000000001
md"""
Avalie a exatidão da seguinte afirmação: "A recente valorização do dólar americano teve um efeito negativo na curva da procura agregada dos EUA."

**a)** Uma apreciação do dólar americano levará a uma diminuição das exportações liquidas dos EUA. Portanto, a procura agregada diminuirá, e a frase está correta.

**b)** Uma apreciação do dólar americano levará a um aumento das exportações liquidas dos EUA. Portanto, a procura agregada aumentará, e a frase está incorreta.

**c)** Uma apreciação do dólar americano não terá qualquer impacto sobre as exportações liquidas dos EUA. Portanto, a procura agregada diminuirá, e a frase está incorreta.

**d)** As exportações líquidas dos EUA não dependem do valor do dólar americano, mas sim de forças não cambiais; portanto a frase não faz qualquer sentido.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0025-000000000002
@bind q25 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0026-000000000001
md"""
Um choque permanente positivo na oferta agregada:

**a)** Torna a economia menos eficiente.

**b)** Promove aumentos da taxa de inflação.

**c)** Diminui o produto agregado no longo prazo.

**d)** Pode ser causado pela adoção de regulamentações imprudentes.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0026-000000000002
@bind q26 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0027-000000000001
md"""
De acordo com o mecanismo de auto-correção, após um choque negativo sobre a procura agregada, como regressa o PIB ao valor do PIB potencial?

**a)** O choque negativo sobre a procura faz o produto agregado aumentar para cada nível da taxa de inflação, promovendo um hiato do produto (output gap) positivo, o que faz a inflação aumentar.

**b)** A inflação esperada diminui, deslocando a curva da oferta agregada de curto prazo para baixo e ao longo da nova curva da procura agregada.

**c)** Inflação mais baixa leva a uma resposta automática do Banco de Central para diminuir a taxa de juro real, estimulando a despesa planeada, aumentando o produto agregado e diminuindo o hiato do produto (output gap).

**d)** O choque negativo sobre a procura faz o produto agregado aumentar para cada nível da taxa de inflação, promovendo um hiato do produto (output gap) negativo, o que faz a inflação diminuir.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0027-000000000002
@bind q27 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0028-000000000001
md"""
Quando Paul Volcker assumiu o cargo de novo Governador do Federal Reserve em 1979, a taxa de inflação ultrapassava os 10%. Em 1982, a taxa de desemprego disparou para 9,7% e a inflação caiu para 6.2%. Qual das seguintes opções é uma descrição apropriada do mecanismo por detrás da desinflação de Volcker?

**a)** A curva AD provavelmente deslocou-se para a esquerda devido à política monetária menos restritiva que explica a redução da taxa de inflação entre 1979 e 1982.

**b)** Devido à política monetária mais restritiva, hiato do produto (output gap) tornou-se negativo, o que explica o aumento da taxa de desemprego entre 1979 e 1982.

**c)** Em 1982, é provável que o produto agregado de equilíbrio fosse superior do que o potencial, levando a curva AS a deslocar-se para a esquerda para o eliminar, o que explica a redução da taxa de desemprego e a redução adicional da inflação entre 1982 e 1986.

**d)** Ao diminuir a Federal Funds Rate, a Reserva Federal acelerou a economia e conseguiu cortar a inflação pela metade em 1982 ao custo de um aumento substancial na taxa de desemprego, causando uma recessão.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0028-000000000002
@bind q28 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0029-000000000000
md"""
`Yp_shock = `$(@bind Yp_shock Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 20222023-0236-0003-0029-000000000010
let
Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ; r̄5 = 0.5 # Demand 
γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; # Supply 
πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       # The AD curve y-axis' intercept 
πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shock) + ρ5           # The AS curve y-axis' intercept
Y5 = 9.0:0.01:11.0
Y5_ΔĀ5 = 8.0:0.02:15.0
r5 = 0.0:0.005:5.0
 
πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
πs5 = πs_min5 .+ γ5 .*Y5    
πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5

trace9_0 = scatter(; x = [10+Yp_shock,10+Yp_shock], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
line_color = "Orange")
trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
name  = "AD")
trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
name  = "AS")
trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", marker_size= "12",
marker_color="Blue", textcolor = "Black",
textfont = attr(family="sans serif", size=18, color="black")) 
layout9_5 = Layout(;
title_text = "Macroeconomic Equilibrium",
title_x = 0.5,
hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8], 
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0])
   p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
name  = "MP") 
trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", 
marker_size= "12", marker_color="Brown", 
textfont = attr(family="sans serif", size=18, color="black"))
layout4_3 = Layout(;
title_text = "MP Curve",
title_x = 0.5,
hovermode = "x",
                xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                xaxis_range = [0.5, 3.5],
xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0]) 
p4_3 = Plot([trace4_0, trace4_1], layout4_3)
[p4_3 p9_4]
end

# ╔═╡ 20222023-0236-0003-0029-000000000001
md"""
As figuras acima representam o equilíbrio macroeconómico inicial. Suponha que há um choque permanente sobre a oferta, de tal forma que o PIB potencial aumenta em +0.6 triliões de dólares. Usando o slider ` Yp_shock` para representar este choque, quais dos valores abaixo correspondem ao novo equilíbrio de _longo prazo_?

**a)** $\pi=2\% \ \  , \ \ Y = 10.3 \ \ , \ \ r=5\% \ \ , \ \ i=3\%$.

**b)** $\pi=1\% \ \  , \ \ Y = 10.6 \ \ , \ \ r=1\% \ \ , \ \ i=2\%$.

**c)** $\pi=3\% \ \  , \ \ Y = 9.7 \ \ , \ \ r=6\% \ \ , \ \ i=10\%$.

**d)** $\pi=4\% \ \  , \ \ Y = 10 \ \ , \ \ r=0\% \ \ , \ \ i=6\%$.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0029-000000000002
@bind q29 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0030-000000000000
md"""
`Yp_shockb = `$(@bind Yp_shockb Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 20222023-0236-0003-0030-000000000010
let
Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ; r̄5 = 0.5 # Demand 
γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; # Supply 
πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       # The AD curve y-axis' intercept 
πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shockb) + ρ5           # The AS curve y-axis' intercept
Y5 = 9.0:0.01:11.0
Y5_ΔĀ5 = 8.0:0.02:15.0
r5 = 0.0:0.005:5.0
 
πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
πs5 = πs_min5 .+ γ5 .*Y5    
πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5

trace9_0 = scatter(; x = [10+Yp_shockb,10+Yp_shockb], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
line_color = "Orange")
trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
name  = "AD")
trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
name  = "AS")
trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", marker_size= "12",
marker_color="Blue", textcolor = "Black",
textfont = attr(family="sans serif", size=18, color="black")) 
layout9_5 = Layout(;
title_text = "Macroeconomic Equilibrium",
title_x = 0.5,
hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8], 
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0])
   p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
name  = "MP") 
trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", 
marker_size= "12", marker_color="Brown", 
textfont = attr(family="sans serif", size=18, color="black"))
layout4_3 = Layout(;
title_text = "MP Curve",
title_x = 0.5,
hovermode = "x",
                xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                xaxis_range = [0.5, 3.5],
xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0]) 
p4_3 = Plot([trace4_0, trace4_1], layout4_3)
[p4_3 p9_4]
end


# ╔═╡ 20222023-0236-0003-0030-000000000001
md"""
As figuras acima representam o equilíbrio macroeconómico inicial. Suponha que há um choque permanente sobre a oferta, de tal forma que o PIB potencial diminui em --0.6 triliões de dólares. Usando o slider ` Yp_shockb` para representar este choque, quais dos valores abaixo correspondem ao novo equilíbrio de _curto prazo_?

**a)** $\pi=4.12\% \ \  , \ \ Y = 9.68 \ \ , \ \ r=2.56\%$.

**b)** $\pi=1\% \ \  , \ \ Y = 10 \ \ , \ \ r=1.7\%$.

**c)** $\pi=2\% \ \  , \ \ Y = 10 \ \ , \ \ r=3.5\%$.

**d)** $\pi=0\% \ \  , \ \ Y = 10\ \ , \ \ r=1.8\%$.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0030-000000000002
@bind q30 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0031-000000000001
md"""
Considere que a economia se econtra numa recessão. Se o mecanismo de auto-correção não tiver atuado, uma flexibilização da política monetária para promover o emprego tal que $$U=U_n$$ resultará:

**a)** Num aumento da taxa de inflação. 

**b)** Numa diminuição da taxa de inflação.

**c)** Num aumento do PIB potencial.

**d)** Numa diminuição do PIB.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0031-000000000002
@bind q31 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0032-000000000001
md"""
De acordo com a Regra de Taylor, suponha que a inflação é igual à inflação objetivo (target) e o PIB se encontra acima do PIB potencial. Um Banco Central com o objetivo principal de estabilidade de preços deve:

**a)** Não fazer nada, porque a inflação não pode subir quando o desemprego é reduzido.

**b)** Restringir a política monetária, para evitar uma subida na taxa de inflação.

**c)** Não fazer nada, porque estabilizar a atividade económica não é o objetivo principal.

**d)** Facilitar a política monetária, porque evitar taxas de desemprego baixas é mais importante do que evitar baixas taxas de inflação.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0032-000000000002
@bind q32 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0033-000000000001
md"""
Se a taxa de inflação objetivo (target) é igual a 2%, a inflação atual é igual a 2%, e o hiato do produto (output gap) é igual a zero, então de acordo com a regra de Taylor (diferente do Princípio de Taylor), a Fed Funds rate deve ser:

**a)** 0

**b)** 0.02

**c)** 0.04

**d)** 0.03

**e)** Não existem informações suficientes para responder à questão.
"""

# ╔═╡ 20222023-0236-0003-0033-000000000002
@bind q33 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0034-000000000001
md"""
Quantitative easing (um dos tipos de política monetária não convencional), consiste em:

**a)** Comprar ativos financeiros de rendimento variável.

**b)** Comprar ativos de maturidade reduzida.

**c)** Comprar ativos de risco reduzido.

**d)** Comprar uma quantidade reduzida de ativos.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0034-000000000002
@bind q34 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0035-000000000001
md"""
“O BCE considera que a melhor forma de manter a estabilidade de preços é através do objetivo de uma inflação de $2\%$ (“target”). Este objetivo é _simétrico_, o que significa que desvios negativos e positivos da inflação em relação ao objetivo são igualmente indesejáveis". Qual a razão que levou BCE a mudar a sua política de um "ceiling" (ou tecto para a inflação), para “desvios simétricos”?

**a)** Porque, caso contrário, a taxa de inflação na Zona Euro estaria tendencialmente sempre abaixo dos $2\%$.

**b)** Porque o BCE, não sabendo muito bem o que fazer, assim decidiu.

**c)** Porque a Comissão Europeia assim decidiu.

**d)** Porque, caso contrário, a taxa de inflação na Zona Euro estaria tendencialmente sempre acima dos $2\%$.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0035-000000000002
@bind q35 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0036-000000000001
md"""
Até ao ZLB (Zero Lower Bound), a curva MP e a curva AD têm a sua representação normal. Após o ZLB ser atingido:

**a)** A curva MP passa a ter o declive positivo.

**b)** A curva MP passa a ter o declive negativo.

**c)** A curva AD passa a ter o declive negativo.

**d)** As curvas MP e AD passam a ter o mesmo declive.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0036-000000000002
@bind q36 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ bb4a77e6-916c-4d8a-b834-6a36fef20e6f
html"""
<img src="https://vivaldomendes.org/images/Tests/multiplier1.png" style="width:600px" />
"""

# ╔═╡ 20222023-0236-0003-0037-000000000001
md"""
A figura acima mostra três situações diferentes relativamente ao valor do multiplicador fiscal (“fiscal multiplier”). Qual corresponde à situação em que o multiplicador fiscal é mais elevado?

**a)** Caso 3.

**b)** Caso 0.

**c)** Caso 1.

**d)** Caso 2.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0037-000000000002
@bind q37 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0038-000000000001
md"""
Existem argumentos que defendem que a dívida pública é um "fardo". Selecione a opção que suporta esta posição.

**a)** O capital público (autoestradas, escolas, entre outros) aumenta a produtividade futura da economia.

**b)** Níveis elevados de educação e melhor saúde aumentam a produtividade laboral.

**c)** Capital público e capital humano promovem externalidades positivas que aumentam a produtividade no futuro e levam a um maior rendimento e receita fiscal.

**d)** O aumento da dívida pública requer aumento de impostos que produzem distorções na alocação de fundos de investimento e esforço de trabalho.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0038-000000000002
@bind q38 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0039-000000000001
md"""
Grande parte do crescimento combinado da despesa em Segurança Social e os principais programas de saúde, nos EUA, resultam de:

**a)** Crescimento da taxa de desemprego.

**b)** Crescimento da taxa de emprego.

**c)** Crescimento da população ativa.

**d)** Envelhecimento da população.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0039-000000000002
@bind q39 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0040-000000000001
md"""
Considere que a taxa de crescimento do PIB real é dada por $g$, que a taxa de juro real paga sobre a dívida pública é dada por $r_p$ e que o saldo primário do Governo é negativo. Selecione a opção correta.

**a)** Se $g>r_p$ , o nível de dívida pública é insustentável.

**b)** Se $g=r_p$ , o nível de dívida pública é sustentável.

**c)** Se $g<r_p$ , o nível de dívida pública é insustentável.

**d)** $g$ e $r_p$ têm pouco a ver com a sustentabilidade da dívida pública.

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 20222023-0236-0003-0040-000000000002
@bind q40 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 20222023-0236-0003-0000-000000000008
md"""
!!! danger "Instruções finais"

	Concluiu a prova.

	O último passo é confirmar que quer **guardar as suas respostas**, através da **Checkbox depois desta caixa**. Ao carregar, será gerado um **ficheiro `.csv`** na mesma pasta onde está alojado este Notebook.

	**É esse ficheiro que deverá enviar à equipa docente.**

	Antes de enviar, certifique-se que a data/hora do ficheiro fazem sentido. **Só depois deve fechar o Notebook.**
"""

# ╔═╡ 20222023-0236-0003-0000-000000000009
md"""
Confirmo que ao longo da prova procedi sempre de acordo com todas as **normas de ética e de integridade académicas**, isto é, sem qualquer recurso ilícito à luz das normas do ISCTE e, em particular, da Unidade Curricular de Macroeconomia I, pelo que quero **guardar as minhas respostas** a fim de as remeter à equipa docente para o meu trabalho ser devidamente avaliado. $(CheckBox(default=false))

---
"""

# ╔═╡ 51fea41d-0689-4472-80f8-a400f7c999fe
md"## Células auxiliares"

# ╔═╡ 852b8a1e-ee2f-4ff0-b6a1-82c85abb4299
md"### Packages"

# ╔═╡ 433e93a2-492f-4931-9418-20f1296f3051
md"### CSS code"

# ╔═╡ 20222023-0236-0003-0000-000000000002
html"""
<link href="https://fonts.googleapis.com/css?family=Montserrat:300,300italic,700,700italic" rel="stylesheet">

<style>
	main {
		max-width: 1200px;
		padding: 5%;
        display:block;
        margin-left: auto;
        margin-right: auto;
	}
	pluto-output {
		font-family: "Montserrat" !important;
		font-size: 1em;
		line-height: 1.5;
	}
	.plutoui-toc {
		font-family: "Montserrat" !important;
		font-size: 90%;
	}
	.admonition-title {
		font-family: "Montserrat" !important;
	}
	pluto-output h1, h2, h3 {
		font-family: "Montserrat" !important;
		border: none !important;
	}
	pluto-output h1 {
		font-size: 1.8em !important;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
	}
	pluto-output h2 {
		font-size: 1.5em !important;
		margin-top: 1.8em;
		margin-bottom: 1em;
	}
	pluto-output h3 {
		font-size: 1.3em !important;
		margin-top: 1.5em;
		margin-bottom: 1em;
	}
	img:not(picture *) {
		width: 80%;
		display: block;
		margin-left: auto;
		margin-right: auto;
	}
	title {
		font-size: 2.2em;
		display: block;
		font-weight: bold;
		text-align: left;
		margin: 1.5em 0 0em 0;
}
	subtitle {
		font-size: 1.6em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	author {
		display: block;
		text-align: left;
		padding-bottom: 0.8em;
		border-bottom: 3px solid !important;
}
	email {
		display: block;
		text-align: left;
		margin: 0 0 2.5em 0;
}
	semester {
		font-size: 1.3em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	.admonition-title {
		font-size: 125%;
	}
	ol {
		list-style-type: lower-alpha;
	}
	li::marker {
		font-weight: bold;
	}
	li {
		margin-top: 1em !important;
		margin-bottom: 1em !important;
	}
	.small {
		font-size: 80%;
	}
	.centered-image {
		display: block;
		margin-left: auto;
		margin-right: auto;
		margin-top: 1em;
		margin-bottom: 1em;
		width: 90%;
	}
	details {
		font-size: 80%;
		margin-left: 3em;
	}
	summary {
		font-size: 125%;
		margin-left: -2.2em;
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	input[type="checkbox"] {
		transform: scale(1.5);
	}
	textarea, input[type="text"] {
		font-family: "Montserrat" !important;
		font-size: 0.85em !important;
		line-height: 1.5;
	}
    pluto-cell>button,pluto-input>button,pluto-shoulder {
    display: none !important;
    } 
</style>
"""

# ╔═╡ bdf49d4c-985d-457e-b31f-7aab9a17552c
md"### Internal functions"

# ╔═╡ 20222023-0236-0003-0000-000000000001
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Por favor selecione uma resposta.*
		
		---
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Correto!"

			---
			"""
		else	
			md"""
			!!! danger "👎 Resposta errada"
				
				Tente outra vez. **Mas estude primeiro!!!** 😡

			---
			"""
		end
	end
end;

# ╔═╡ 20222023-0236-0003-0001-000000000003
tchanã(q01,"a)")

# ╔═╡ 20222023-0236-0003-0002-000000000003
tchanã(q02,"c)")

# ╔═╡ 20222023-0236-0003-0003-000000000003
tchanã(q03,"c)")

# ╔═╡ 20222023-0236-0003-0004-000000000003
tchanã(q04,"e)")

# ╔═╡ 20222023-0236-0003-0005-000000000003
tchanã(q05,"b)")

# ╔═╡ 20222023-0236-0003-0006-000000000003
tchanã(q06,"a)")

# ╔═╡ 20222023-0236-0003-0007-000000000003
tchanã(q07,"d)")

# ╔═╡ 20222023-0236-0003-0008-000000000003
tchanã(q08,"c)")

# ╔═╡ 20222023-0236-0003-0009-000000000003
tchanã(q09,"b)")

# ╔═╡ 20222023-0236-0003-0010-000000000003
tchanã(q10,"b)")

# ╔═╡ 20222023-0236-0003-0011-000000000003
tchanã(q11,"a)")

# ╔═╡ 20222023-0236-0003-0012-000000000003
tchanã(q12,"b)")

# ╔═╡ 20222023-0236-0003-0013-000000000003
tchanã(q13,"a)")

# ╔═╡ 20222023-0236-0003-0014-000000000003
tchanã(q14,"e)")

# ╔═╡ 20222023-0236-0003-0015-000000000003
tchanã(q15,"d)")

# ╔═╡ 20222023-0236-0003-0016-000000000003
tchanã(q16,"a)")

# ╔═╡ 20222023-0236-0003-0017-000000000003
tchanã(q17,"a)")

# ╔═╡ 20222023-0236-0003-0018-000000000003
tchanã(q18,"e)")

# ╔═╡ 20222023-0236-0003-0019-000000000003
tchanã(q19,"c)")

# ╔═╡ 20222023-0236-0003-0020-000000000003
tchanã(q20,"a)")

# ╔═╡ 20222023-0236-0003-0021-000000000003
tchanã(q21,"d)")

# ╔═╡ 20222023-0236-0003-0022-000000000003
tchanã(q22,"a)")

# ╔═╡ 20222023-0236-0003-0023-000000000003
tchanã(q23,"d)")

# ╔═╡ 20222023-0236-0003-0024-000000000003
tchanã(q24,"a)")

# ╔═╡ 20222023-0236-0003-0025-000000000003
tchanã(q25,"a)")

# ╔═╡ 20222023-0236-0003-0026-000000000003
tchanã(q26,"e)")

# ╔═╡ 20222023-0236-0003-0027-000000000003
tchanã(q27,"b)")

# ╔═╡ 20222023-0236-0003-0028-000000000003
tchanã(q28,"b)")

# ╔═╡ 20222023-0236-0003-0029-000000000003
tchanã(q29,"b)")

# ╔═╡ 20222023-0236-0003-0030-000000000003
tchanã(q30,"a)")

# ╔═╡ 20222023-0236-0003-0031-000000000003
tchanã(q31,"a)")

# ╔═╡ 20222023-0236-0003-0032-000000000003
tchanã(q32,"b)")

# ╔═╡ 20222023-0236-0003-0033-000000000003
tchanã(q33,"e)")

# ╔═╡ 20222023-0236-0003-0034-000000000003
tchanã(q34,"e)")

# ╔═╡ 20222023-0236-0003-0035-000000000003
tchanã(q35,"a)")

# ╔═╡ 20222023-0236-0003-0036-000000000003
tchanã(q36,"b)")

# ╔═╡ 20222023-0236-0003-0037-000000000003
tchanã(q37,"a)")

# ╔═╡ 20222023-0236-0003-0038-000000000003
tchanã(q38,"d)")

# ╔═╡ 20222023-0236-0003-0039-000000000003
tchanã(q39,"d)")

# ╔═╡ 20222023-0236-0003-0040-000000000003
tchanã(q40,"c)")



# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoTeachingTools = "661c6b06-c737-4d37-b85c-46df65de6f69"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
StatsBase = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"

[compat]
CSV = "~0.10.10"
DataFrames = "~1.5.0"
HypertextLiteral = "~0.9.4"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoTeachingTools = "~0.2.11"
PlutoUI = "~0.7.51"
StatsBase = "~0.34.0"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.9.3"
manifest_format = "2.0"
project_hash = "7844394d0b300f9e0571a750b51d08b1e8c515de"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "91bd53c39b9cbfb5ef4b015e8b582d344532bd0a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.2.0"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "44dbf560808d49041989b8a96cae4cffbeb7966a"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.11"

[[deps.CodeTracking]]
deps = ["InteractiveUtils", "UUIDs"]
git-tree-sha1 = "a1296f0fe01a4c3f9bf0dc2934efbf4416f5db31"
uuid = "da1fd8a2-8d9e-5ec2-8556-3022fb5608a2"
version = "1.3.4"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "02aa26a4cf76381be7f66e020a3eddeb27b0a092"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.2"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "d9a8f86737b665e15a9641ecbac64deef9ce6724"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.23.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

    [deps.ColorVectorSpace.weakdeps]
    SpecialFunctions = "276daf66-3868-5448-9aa4-cd146d93841b"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.Compat]]
deps = ["UUIDs"]
git-tree-sha1 = "e460f044ca8b99be31d35fe54fc33a5c33dd8ed7"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.9.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+0"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "8da84edb865b0b5b0100c0666a9bc9a0b71c553c"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.15.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SentinelArrays", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "aa51303df86f8626a962fccb878430cdb0a97eee"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.5.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "3dbd312d370723b6bb43ba9d02fc36abade4518d"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.15"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "e27c4ebe80e8699540f2d6c805cc12203b614f12"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.20"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.Formatting]]
deps = ["Printf"]
git-tree-sha1 = "8339d61043228fdd3eb658d86c926cb282ae72a8"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.2"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "d75853a0bdbfb1ac815478bacd89cd27b550ace6"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.3"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.JuliaInterpreter]]
deps = ["CodeTracking", "InteractiveUtils", "Random", "UUIDs"]
git-tree-sha1 = "81dc6aefcbe7421bd62cb6ca0e700779330acff8"
uuid = "aa1ae85d-cabe-5617-a682-6adf51b2e16a"
version = "0.9.25"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.Latexify]]
deps = ["Formatting", "InteractiveUtils", "LaTeXStrings", "MacroTools", "Markdown", "OrderedCollections", "Printf", "Requires"]
git-tree-sha1 = "f428ae552340899a935973270b8d98e5a31c49fe"
uuid = "23fbe1c1-3f47-55db-b15f-69d7ec21a316"
version = "0.16.1"

    [deps.Latexify.extensions]
    DataFramesExt = "DataFrames"
    SymEngineExt = "SymEngine"

    [deps.Latexify.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    SymEngine = "123dc426-2d89-5057-bbad-38513e3affd8"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "7d6dd4e9212aebaeed356de34ccf262a3cd415aa"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.26"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.LoweredCodeUtils]]
deps = ["JuliaInterpreter"]
git-tree-sha1 = "60168780555f3e663c536500aa790b6368adc02a"
uuid = "6f1432cf-f94c-5a45-995e-cdbf5db27b0b"
version = "2.3.0"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "9ee1618cbf5240e6d4e0371d6f24065083f60c48"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.11"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "f66bdc5de519e8f8ae43bdc598782d35a25b1272"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.1.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.10.11"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.21+4"

[[deps.OrderedCollections]]
git-tree-sha1 = "2e73fe17cac3c62ad1aebe70d44c963c3cfdc3e3"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.2"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "716e24b21538abc91f6205fd1d8363f39b442851"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.7.2"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.9.2"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoHooks]]
deps = ["InteractiveUtils", "Markdown", "UUIDs"]
git-tree-sha1 = "072cdf20c9b0507fdd977d7d246d90030609674b"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0774"
version = "0.0.5"

[[deps.PlutoLinks]]
deps = ["FileWatching", "InteractiveUtils", "Markdown", "PlutoHooks", "Revise", "UUIDs"]
git-tree-sha1 = "8f5fa7056e6dcfb23ac5211de38e6c03f6367794"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0420"
version = "0.1.6"

[[deps.PlutoTeachingTools]]
deps = ["Downloads", "HypertextLiteral", "LaTeXStrings", "Latexify", "Markdown", "PlutoLinks", "PlutoUI", "Random"]
git-tree-sha1 = "542de5acb35585afcf202a6d3361b430bc1c3fbd"
uuid = "661c6b06-c737-4d37-b85c-46df65de6f69"
version = "0.2.13"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "e47cd150dbe0443c3a3651bc5b9cbd5576ab75b7"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.52"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "a6062fe4063cdafe78f4a0a81cfffb89721b30e7"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.2"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "03b4c25b43cb84cee5c90aa9b5ea0a78fd848d2f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.0"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "7eb1686b4f04b82f96ed7a4ea5890a4f0c7a09f1"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.0"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "ee094908d720185ddbdc58dbe0c1cbe35453ec7a"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.2.7"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.Revise]]
deps = ["CodeTracking", "Distributed", "FileWatching", "JuliaInterpreter", "LibGit2", "LoweredCodeUtils", "OrderedCollections", "Pkg", "REPL", "Requires", "UUIDs", "Unicode"]
git-tree-sha1 = "1e597b93700fa4045d7189afa7c004e0584ea548"
uuid = "295af30f-e4ad-537b-8983-00126c2a3abe"
version = "3.5.3"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "04bdff0b09c65ff3e06a05e3eb7b120223da3d39"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "c60ec5c62180f27efea3ba2908480f8055e17cee"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.1.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.9.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "45a7769a04a3cf80da1c1c7c60caf932e6f4c9f7"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.6.0"

[[deps.StatsBase]]
deps = ["DataAPI", "DataStructures", "LinearAlgebra", "LogExpFunctions", "Missings", "Printf", "Random", "SortingAlgorithms", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "75ebe04c5bed70b91614d684259b661c9e6274a4"
uuid = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"
version = "0.34.0"

[[deps.StringManipulation]]
git-tree-sha1 = "46da2434b41f41ac3594ee9816ce5541c6096123"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.0"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "Pkg", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "5.10.1+6"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits", "Test"]
git-tree-sha1 = "1544b926975372da01227b382066ab70e574a3ec"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.10.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
deps = ["Random", "Test"]
git-tree-sha1 = "9a6ae7ed916312b41236fcef7e0af564ef934769"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.9.13"

[[deps.Tricks]]
git-tree-sha1 = "aadb748be58b492045b4f56166b5188aa63ce549"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.7"

[[deps.URIs]]
git-tree-sha1 = "b7a5e99f24892b6824a954199a45e9ffcc1c70f0"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.0"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+0"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─20222023-0236-0003-0000-000000000003
# ╟─20222023-0236-0003-0000-000000000004
# ╟─20222023-0236-0003-0000-000000000005
# ╟─20222023-0236-0003-0000-000000000006
# ╟─20222023-0236-0003-0000-000000000007
# ╟─46598cde-557e-4564-958b-9d3c3df029ed
# ╟─20222023-0236-0003-0001-000000000001
# ╟─20222023-0236-0003-0001-000000000002
# ╟─20222023-0236-0003-0001-000000000003
# ╟─20222023-0236-0003-0002-000000000001
# ╟─20222023-0236-0003-0002-000000000002
# ╟─20222023-0236-0003-0002-000000000003
# ╟─20222023-0236-0003-0003-000000000001
# ╟─20222023-0236-0003-0003-000000000002
# ╟─20222023-0236-0003-0003-000000000003
# ╟─20222023-0236-0003-0004-000000000001
# ╟─20222023-0236-0003-0004-000000000002
# ╟─20222023-0236-0003-0004-000000000003
# ╟─20222023-0236-0003-0005-000000000000
# ╟─20222023-0236-0003-0005-000000000001
# ╠═a427ead0-0317-4c00-9cf8-fb162cd771c2
# ╠═5a10b2ee-1cc6-4bdd-b793-d7e584b410e5
# ╠═38424a48-bc9e-471d-9773-171fd8effb55
# ╟─20222023-0236-0003-0005-000000000002
# ╟─20222023-0236-0003-0005-000000000003
# ╟─20222023-0236-0003-0006-000000000001
# ╟─20222023-0236-0003-0006-000000000002
# ╟─20222023-0236-0003-0006-000000000003
# ╟─20222023-0236-0003-0007-000000000001
# ╟─20222023-0236-0003-0007-000000000002
# ╟─20222023-0236-0003-0007-000000000003
# ╟─20222023-0236-0003-0008-000000000001
# ╟─20222023-0236-0003-0008-000000000002
# ╟─20222023-0236-0003-0008-000000000003
# ╟─20222023-0236-0003-0009-000000000010
# ╟─20222023-0236-0003-0009-000000000001
# ╟─20222023-0236-0003-0009-000000000002
# ╟─20222023-0236-0003-0009-000000000003
# ╟─20222023-0236-0003-0010-000000000001
# ╟─20222023-0236-0003-0010-000000000002
# ╟─20222023-0236-0003-0010-000000000003
# ╟─9031631e-3aa7-46de-973d-dbfa668bf18b
# ╟─bece237e-83f1-41b5-a759-1c2934ddc57b
# ╟─20222023-0236-0003-0011-000000000001
# ╟─20222023-0236-0003-0011-000000000002
# ╟─20222023-0236-0003-0011-000000000003
# ╟─2d8c34ef-9697-4d36-a66c-83fc800ef447
# ╟─20222023-0236-0003-0012-000000000001
# ╟─20222023-0236-0003-0012-000000000002
# ╟─20222023-0236-0003-0012-000000000003
# ╟─be4a5d64-8da8-419e-9b5c-4b66aac99cc4
# ╟─20222023-0236-0003-0013-000000000001
# ╟─20222023-0236-0003-0013-000000000002
# ╟─20222023-0236-0003-0013-000000000003
# ╟─20222023-0236-0003-0014-000000000001
# ╟─20222023-0236-0003-0014-000000000002
# ╟─20222023-0236-0003-0014-000000000003
# ╟─b31c69f6-b072-4e95-aada-3d07a0e89481
# ╟─20222023-0236-0003-0015-000000000001
# ╟─20222023-0236-0003-0015-000000000002
# ╟─20222023-0236-0003-0015-000000000003
# ╟─f39350c4-2bf9-4e4a-8b8f-01bb4da07dc7
# ╟─20222023-0236-0003-0016-000000000001
# ╟─20222023-0236-0003-0016-000000000002
# ╟─20222023-0236-0003-0016-000000000003
# ╟─20222023-0236-0003-0017-000000000001
# ╟─20222023-0236-0003-0017-000000000002
# ╟─20222023-0236-0003-0017-000000000003
# ╟─20222023-0236-0003-0018-000000000001
# ╟─20222023-0236-0003-0018-000000000002
# ╟─20222023-0236-0003-0018-000000000003
# ╟─20222023-0236-0003-0019-000000000000
# ╟─20222023-0236-0003-0019-000000000001
# ╠═f87ae88e-587e-4b9a-98b7-b2e4f4d72f90
# ╟─20222023-0236-0003-0019-000000000002
# ╟─20222023-0236-0003-0019-000000000003
# ╟─20222023-0236-0003-0020-000000000001
# ╟─20222023-0236-0003-0020-000000000002
# ╟─20222023-0236-0003-0020-000000000003
# ╟─20222023-0236-0003-0021-000000000000
# ╟─20222023-0236-0003-0021-000000000001
# ╟─20222023-0236-0003-0021-000000000002
# ╟─20222023-0236-0003-0021-000000000003
# ╟─20222023-0236-0003-0022-000000000001
# ╟─20222023-0236-0003-0022-000000000002
# ╟─20222023-0236-0003-0022-000000000003
# ╟─20222023-0236-0003-0023-000000000001
# ╟─20222023-0236-0003-0023-000000000002
# ╟─20222023-0236-0003-0023-000000000003
# ╟─20222023-0236-0003-0024-000000000001
# ╟─20222023-0236-0003-0024-000000000002
# ╟─20222023-0236-0003-0024-000000000003
# ╟─20222023-0236-0003-0025-000000000001
# ╟─20222023-0236-0003-0025-000000000002
# ╟─20222023-0236-0003-0025-000000000003
# ╟─20222023-0236-0003-0026-000000000001
# ╟─20222023-0236-0003-0026-000000000002
# ╟─20222023-0236-0003-0026-000000000003
# ╟─20222023-0236-0003-0027-000000000001
# ╟─20222023-0236-0003-0027-000000000002
# ╟─20222023-0236-0003-0027-000000000003
# ╟─20222023-0236-0003-0028-000000000001
# ╟─20222023-0236-0003-0028-000000000002
# ╟─20222023-0236-0003-0028-000000000003
# ╟─20222023-0236-0003-0029-000000000000
# ╟─20222023-0236-0003-0029-000000000010
# ╟─20222023-0236-0003-0029-000000000001
# ╟─20222023-0236-0003-0029-000000000002
# ╟─20222023-0236-0003-0029-000000000003
# ╟─20222023-0236-0003-0030-000000000000
# ╟─20222023-0236-0003-0030-000000000010
# ╟─20222023-0236-0003-0030-000000000001
# ╟─20222023-0236-0003-0030-000000000002
# ╟─20222023-0236-0003-0030-000000000003
# ╟─20222023-0236-0003-0031-000000000001
# ╟─20222023-0236-0003-0031-000000000002
# ╟─20222023-0236-0003-0031-000000000003
# ╟─20222023-0236-0003-0032-000000000001
# ╟─20222023-0236-0003-0032-000000000002
# ╟─20222023-0236-0003-0032-000000000003
# ╟─20222023-0236-0003-0033-000000000001
# ╟─20222023-0236-0003-0033-000000000002
# ╟─20222023-0236-0003-0033-000000000003
# ╟─20222023-0236-0003-0034-000000000001
# ╟─20222023-0236-0003-0034-000000000002
# ╟─20222023-0236-0003-0034-000000000003
# ╟─20222023-0236-0003-0035-000000000001
# ╟─20222023-0236-0003-0035-000000000002
# ╟─20222023-0236-0003-0035-000000000003
# ╟─20222023-0236-0003-0036-000000000001
# ╟─20222023-0236-0003-0036-000000000002
# ╟─20222023-0236-0003-0036-000000000003
# ╟─bb4a77e6-916c-4d8a-b834-6a36fef20e6f
# ╟─20222023-0236-0003-0037-000000000001
# ╟─20222023-0236-0003-0037-000000000002
# ╟─20222023-0236-0003-0037-000000000003
# ╟─20222023-0236-0003-0038-000000000001
# ╟─20222023-0236-0003-0038-000000000002
# ╟─20222023-0236-0003-0038-000000000003
# ╟─20222023-0236-0003-0039-000000000001
# ╟─20222023-0236-0003-0039-000000000002
# ╟─20222023-0236-0003-0039-000000000003
# ╟─20222023-0236-0003-0040-000000000001
# ╟─20222023-0236-0003-0040-000000000002
# ╟─20222023-0236-0003-0040-000000000003
# ╟─20222023-0236-0003-0000-000000000008
# ╟─20222023-0236-0003-0000-000000000009
# ╟─51fea41d-0689-4472-80f8-a400f7c999fe
# ╟─852b8a1e-ee2f-4ff0-b6a1-82c85abb4299
# ╠═20222023-0236-0003-0000-000000000000
# ╟─433e93a2-492f-4931-9418-20f1296f3051
# ╟─20222023-0236-0003-0000-000000000002
# ╟─bdf49d4c-985d-457e-b31f-7aab9a17552c
# ╟─20222023-0236-0003-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
